/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.mobile.api.facade.connectors.impl;

import java.nio.charset.Charset;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.ArrayNode;
import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.connectors.BaseConnector;
import com.openexchange.mobile.api.facade.connectors.RequestConfiguration;
import com.openexchange.mobile.api.facade.connectors.responses.RawResponseMto;

import org.apache.http.HttpEntity;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.client.methods.RequestBuilder;
import org.apache.http.entity.StringEntity;

public class GetJsLobConnector extends BaseConnector<RawResponseMto> {

    private String name;

    public GetJsLobConnector(RequestConfiguration configuration, SessionData sessionData, String name) {
        super(configuration, sessionData, "jslob", RawResponseMto.class);
        this.name = name;
    }

    @Override
    protected HttpUriRequest createRequest() {
        RequestBuilder builder = RequestBuilder.put(createUrl());
        builder.setCharset(Charset.forName("UTF-8"));
        addSessionData(builder);
        builder.addParameter("action", "list");
        builder.setEntity(createEntity());
        return builder.build();
    }

    private HttpEntity createEntity() {
        String str = String.format("[\"%s\"]", name);
        return new StringEntity(str, "utf-8");
    }

    public static JsonNode map(RawResponseMto response) {
        if (response == null) {
            return null;
        }
        JsonNode data = response.getData();
        if (data == null || !data.isArray()) {
            return null;
        }
        JsonNode node = ((ArrayNode) data).get(0);
        if (node == null) {
            return node;
        }
        return node.get("tree");
    }

}