/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.mobile.api.facade.endpoints.responses.ctos;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.openexchange.mobile.api.facade.models.Contact;
import com.openexchange.mobile.api.facade.models.DistributionEntry;
import com.openexchange.mobile.api.facade.utils.ListUtil;
import com.openexchange.mobile.api.facade.utils.MapFunction;

import lombok.Value;

@Value
@JsonInclude(JsonInclude.Include.NON_NULL)
public class ContactCto {

    String displayName;

    String firstName;

    String lastName;

    String email1;

    String email2;

    String email3;

    String imageUrl;

    List<DistributionEntryCto> distributionList;

    private static final MapFunction<DistributionEntry, DistributionEntryCto> distributionEntryMapFunction = new MapFunction<DistributionEntry, DistributionEntryCto>() {
        @Override
        public DistributionEntryCto map(DistributionEntry entry) {
            return new DistributionEntryCto(entry);
        }
    };

    public ContactCto(Contact contact) {
        displayName = contact.getDisplayName();
        firstName = contact.getFirstName();
        lastName = contact.getLastName();
        email1 = contact.getEmail1();
        email2 = contact.getEmail2();
        email3 = contact.getEmail3();
        imageUrl = contact.getImageUrl();
        distributionList = ListUtil.map(contact.getDistributionList(), distributionEntryMapFunction);
    }

}
